"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var os_1 = require("os");
var sequence_1 = require("@typed/sequence");
var helpers_1 = require("../../../helpers");
var splitVersion_1 = require("./splitVersion");
var incrementName_1 = require("./incrementName");
var getNewVersion_1 = require("./getNewVersion");
var getPackagesToUpdate_1 = require("./getPackagesToUpdate");
function bumpPackageVersions(config, io, options, affectedPackages) {
    var packages = config.packages;
    var affectedPackageNames = Object.keys(affectedPackages);
    var packagesToUpdate = getPackagesToUpdate_1.getPackagesToUpdate(packages, affectedPackageNames);
    var method = options.semver ? 'semver' : options.comver ? 'comver' : 'semver';
    return performVersionBump(packagesToUpdate, affectedPackages, io, method);
}
exports.bumpPackageVersions = bumpPackageVersions;
function performVersionBump(packagesToUpdate, affectedPackages, io, method) {
    var newPackages = [];
    return sequence_1.sequence(packagesToUpdate, bumpVersion(affectedPackages, io, method, newPackages))
        .then(function () { return newPackages.filter(Boolean); });
}
;
function bumpVersion(affectedPackages, io, method, newPackages) {
    return function (packageToUpdate) {
        var pkg = packageToUpdate.pkg, name = packageToUpdate.name, directory = packageToUpdate.directory;
        var commits = affectedPackages[name].commits;
        var suggestedUpdate = helpers_1.getSuggestedUpdate(commits, method);
        var increment = incrementName_1.incrementName(suggestedUpdate);
        if (!increment)
            return Promise.resolve(void 0);
        var newVersion = getNewVersion_1.getNewVersion(splitVersion_1.splitVersion(pkg.version), suggestedUpdate);
        io.stdout.write("Bumping " + name + " version from " + pkg.version + " to " + newVersion + "..." + os_1.EOL + os_1.EOL);
        var message = "chore(release): v" + newVersion + " [ci skip]" + os_1.EOL + os_1.EOL +
            ("AFFECTS: " + name);
        var newPackage = { pkg: __assign({}, pkg, { version: newVersion }), name: name, directory: directory, commits: commits };
        newPackages.push(newPackage);
        return helpers_1.execute('npm', [
            'version',
            '--no-git-tag-version',
            increment,
        ], io, directory)
            .then(function () { return helpers_1.execute('git', ['add', 'package.json'], io, directory); })
            .then(function () { return helpers_1.execute('git', ['commit', '-m', message], io, directory); });
    };
}
;
//# sourceMappingURL=bumpPackageVersions.js.map